# V1alpha1Inputs

Inputs are the mechanism for passing parameters, artifacts, volumes from one template to another
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**artifacts** | [**list[V1alpha1Artifact]**](V1alpha1Artifact.md) | Artifact are a list of artifacts passed as inputs | [optional] 
**parameters** | [**list[V1alpha1Parameter]**](V1alpha1Parameter.md) | Parameters are a list of parameters passed as inputs | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


